@@ -2,8 +2,8 @@
 // vim: expandtab sw=4 ts=4 sts=4:
 
 // This is main file for Ukolovnik
-// Copyright © 2005 - 2009 Michal Čihař
-// Published under GNU GPL version 2
+// Copyright © 2005 - 2016 Michal Čihař
+// Published under GNU GPL version 3 or later
 
 // Grab needed libaries
 require_once('./lib/version.php');
@@ -36,7 +36,7 @@ if (substr($cmd, 0, 7) == 'export_') {
 }
 
 // Include correct language file
-$failed_lang = LOCALE_init();
+LOCALE_init();
 
 HTTP_nocache_headers();
 
@@ -44,14 +44,40 @@ if ($show_html) {
     HTML_header();
 }
 
+/**
+ * Returns HTML for checked attribute
+ *
+ * @param string $name Name of parameter
+ *
+ * @return string
+ */
 function get_check($name) {
     return isset($_REQUEST[$name]) ? 'checked="checked" ' : '';
 }
 
+/**
+ * Returns option valud
+ *
+ * @param string $name    Name of option
+ * @param string $default Default value
+ *
+ * @return string
+ */
 function get_opt($name, $default = '') {
     return empty($_REQUEST[$name]) ? $default : htmlspecialchars($_REQUEST[$name]);
 }
 
+/**
+ * Returns HTML for select
+ *
+ * @param string   $name      Name of element
+ * @param string   $default   Default value
+ * @param string[] $options   Options to list
+ * @param boolean $add_any    Add "Any" option
+ * @param boolean $autosubmit If the form should autosubmit on change
+ *
+ * @return string
+ */
 function get_select($name, $default, $options, $add_any=FALSE, $autosubmit=FALSE) {
     if (isset($_REQUEST[$name]) && strlen($_REQUEST[$name]) > 0) {
         $default = $_REQUEST[$name];
@@ -78,6 +104,11 @@ function get_select($name, $default, $options, $add_any=FALSE, $autosubmit=FALSE
     return $ret . '</select>';
 }
 
+/**
+ * Returns HTML for task
+ *
+ * @return string
+ */
 function show_edit_task($name, $cmd, $title, $description, $priority, $category, $update_count, $id = NULL) {
     global $priorities, $categories;
 
@@ -98,6 +129,13 @@ function show_edit_task($name, $cmd, $title, $description, $priority, $category,
     echo '<input type="submit" value="' . $name . '"/></form></fieldset>';
 }
 
+
+function check_id_param() {
+    if (!isset($_REQUEST['id'])) {
+        HTML_die_error(_('Invalid parameters.'));
+    }
+}
+
 // Check for extensions
 $check = EXTENSIONS_check();
 
@@ -136,11 +174,6 @@ if (count($check) > 0) {
     HTML_footer();
 }
 
-// Could we locate language file?
-if ($failed_lang) {
-    HTML_message('warning', sprintf(_('Invalid language (%s) has been chosen.'), $language));
-}
-
 if ($show_html) {
     require('./lib/toolbar.php');
 }
@@ -249,9 +282,7 @@ while (!empty($cmd)) {
             $cmd = '';
             break;
         case 'show':
-            if (!isset($_REQUEST['id'])) {
-                HTML_die_error(_('Invalid parameters.'));
-            }
+            check_id_param();
             $q = SQL_do('SELECT id,category,UNIX_TIMESTAMP(created) AS created,priority,title,UNIX_TIMESTAMP(closed) AS closed,UNIX_TIMESTAMP(updated) AS updated,description FROM ' . $GLOBALS['table_prefix'] . 'tasks WHERE id=' . (int)$_REQUEST['id']);
             if (mysql_num_rows($q) != 1) {
                 HTML_message('notice', _('No entries found.'));
@@ -283,9 +314,7 @@ while (!empty($cmd)) {
             $cmd = '';
             break;
         case 'reopen':
-            if (!isset($_REQUEST['id'])) {
-                HTML_die_error(_('Invalid parameters.'));
-            }
+            check_id_param();
             $q = SQL_do('SELECT title FROM ' . $GLOBALS['table_prefix'] . 'tasks WHERE id=' . (int)$_REQUEST['id']);
             if (mysql_num_rows($q) != 1) {
                 HTML_message('notice', _('No entries found.'));
@@ -298,9 +327,7 @@ while (!empty($cmd)) {
             $cmd = 'list';
             break;
         case 'fin':
-            if (!isset($_REQUEST['id'])) {
-                HTML_die_error(_('Invalid parameters.'));
-            }
+            check_id_param();
             $q = SQL_do('SELECT title FROM ' . $GLOBALS['table_prefix'] . 'tasks WHERE id=' . (int)$_REQUEST['id']);
             if (mysql_num_rows($q) != 1) {
                 HTML_message('notice', _('No entries found.'));
@@ -313,9 +340,7 @@ while (!empty($cmd)) {
             $cmd = 'list';
             break;
         case 'del':
-            if (!isset($_REQUEST['id'])) {
-                HTML_die_error(_('Invalid parameters.'));
-            }
+            check_id_param();
             $q = SQL_do('SELECT title FROM ' . $GLOBALS['table_prefix'] . 'tasks WHERE id=' . (int)$_REQUEST['id']);
             if (mysql_num_rows($q) != 1) {
                 HTML_message('notice', _('No entries found.'));
@@ -735,7 +760,7 @@ while (!empty($cmd)) {
             break;
         case 'about':
             echo '<h3>' . _('About Ukolovnik') . '</h3>';
-            echo '<p>' . _('Ukolovnik is simple todo manager licensed under GNU/GPL version 2.') . '</p>';
+            echo '<p>' . _('Ukolovnik is simple todo manager licensed under GNU GPL version 3 or later.') . '</p>';
             echo '<p>';
             $url = LOCALE_url('cihar.com/software/ukolovnik');
             printf(_('It has homepage on %s.'), '<a href="http://' . $url . '/">' . $url . '</a>');
@@ -807,7 +832,7 @@ while (!empty($cmd)) {
             $cmd = '';
             break;
         default:
-            HTML_message('error', _('Uknonwn command! Maybe you hit some not yet implemented functionality.'));
+            HTML_message('error', _('Unknown command! Maybe you hit some not yet implemented functionality.'));
             $cmd = '';
             break;
     }
@@ -815,4 +840,3 @@ while (!empty($cmd)) {
 if ($show_html) {
     HTML_footer();
 }
-?>
