@@ -2,11 +2,8 @@
 // vim: expandtab sw=4 ts=4 sts=4:
 
 // This is HTTP handling stuff for Ukolovnik
-// Copyright © 2005 - 2009 Michal Čihař
-// Published under GNU GPL version 2
-
-// Grab needed libraries
-require_once('./lib/compat.php');
+// Copyright © 2005 - 2016 Michal Čihař
+// Published under GNU GPL version 3 or later
 
 /**
  * Outputs headers to disable caching.
@@ -24,7 +21,7 @@ function HTTP_nocache_headers() {
 
 /**
  * Outputs http header with content type.
- * @param string content type
+ * @param string $type content type
  */
 function HTTP_type_header($type) {
     header('Content-Type: ' . $type);
@@ -35,7 +32,6 @@ function HTTP_type_header($type) {
  */
 function HTTP_clean_request() {
     if (get_magic_quotes_gpc()) {
-        arrayWalkRecursive($_REQUEST, 'stripslashes');
+        array_walk_recursive($_REQUEST, 'stripslashes');
     }
 }
-?>
